@@ -37,6 +37,7 @@ QueryObjectsPaginatorName = Literal["query_objects"]
 TaskStatusType = Literal["FAILED", "FALSE", "FINISHED"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -69,6 +70,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
