@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import OperatorTypeType, TaskStatusType
 
@@ -83,7 +83,7 @@ _RequiredActivatePipelineInputRequestTypeDef = TypedDict(
 _OptionalActivatePipelineInputRequestTypeDef = TypedDict(
     "_OptionalActivatePipelineInputRequestTypeDef",
     {
-        "parameterValues": List["ParameterValueTypeDef"],
+        "parameterValues": Sequence["ParameterValueTypeDef"],
         "startTimestamp": Union[datetime, str],
     },
     total=False,
@@ -100,7 +100,7 @@ AddTagsInputRequestTypeDef = TypedDict(
     "AddTagsInputRequestTypeDef",
     {
         "pipelineId": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -115,7 +115,7 @@ _OptionalCreatePipelineInputRequestTypeDef = TypedDict(
     "_OptionalCreatePipelineInputRequestTypeDef",
     {
         "description": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -167,7 +167,7 @@ _RequiredDescribeObjectsInputRequestTypeDef = TypedDict(
     "_RequiredDescribeObjectsInputRequestTypeDef",
     {
         "pipelineId": str,
-        "objectIds": List[str],
+        "objectIds": Sequence[str],
     },
 )
 _OptionalDescribeObjectsInputRequestTypeDef = TypedDict(
@@ -199,7 +199,7 @@ DescribeObjectsOutputTypeDef = TypedDict(
 DescribePipelinesInputRequestTypeDef = TypedDict(
     "DescribePipelinesInputRequestTypeDef",
     {
-        "pipelineIds": List[str],
+        "pipelineIds": Sequence[str],
     },
 )
 
@@ -311,7 +311,7 @@ OperatorTypeDef = TypedDict(
     "OperatorTypeDef",
     {
         "type": OperatorTypeType,
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -426,14 +426,14 @@ _RequiredPutPipelineDefinitionInputRequestTypeDef = TypedDict(
     "_RequiredPutPipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
-        "pipelineObjects": List["PipelineObjectTypeDef"],
+        "pipelineObjects": Sequence["PipelineObjectTypeDef"],
     },
 )
 _OptionalPutPipelineDefinitionInputRequestTypeDef = TypedDict(
     "_OptionalPutPipelineDefinitionInputRequestTypeDef",
     {
-        "parameterObjects": List["ParameterObjectTypeDef"],
-        "parameterValues": List["ParameterValueTypeDef"],
+        "parameterObjects": Sequence["ParameterObjectTypeDef"],
+        "parameterValues": Sequence["ParameterValueTypeDef"],
     },
     total=False,
 )
@@ -493,7 +493,7 @@ QueryObjectsOutputTypeDef = TypedDict(
 QueryTypeDef = TypedDict(
     "QueryTypeDef",
     {
-        "selectors": List["SelectorTypeDef"],
+        "selectors": Sequence["SelectorTypeDef"],
     },
     total=False,
 )
@@ -502,7 +502,7 @@ RemoveTagsInputRequestTypeDef = TypedDict(
     "RemoveTagsInputRequestTypeDef",
     {
         "pipelineId": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -515,7 +515,7 @@ _RequiredReportTaskProgressInputRequestTypeDef = TypedDict(
 _OptionalReportTaskProgressInputRequestTypeDef = TypedDict(
     "_OptionalReportTaskProgressInputRequestTypeDef",
     {
-        "fields": List["FieldTypeDef"],
+        "fields": Sequence["FieldTypeDef"],
     },
     total=False,
 )
@@ -590,7 +590,7 @@ SetStatusInputRequestTypeDef = TypedDict(
     "SetStatusInputRequestTypeDef",
     {
         "pipelineId": str,
-        "objectIds": List[str],
+        "objectIds": Sequence[str],
         "status": str,
     },
 )
@@ -642,14 +642,14 @@ _RequiredValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
     "_RequiredValidatePipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
-        "pipelineObjects": List["PipelineObjectTypeDef"],
+        "pipelineObjects": Sequence["PipelineObjectTypeDef"],
     },
 )
 _OptionalValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
     "_OptionalValidatePipelineDefinitionInputRequestTypeDef",
     {
-        "parameterObjects": List["ParameterObjectTypeDef"],
-        "parameterValues": List["ParameterValueTypeDef"],
+        "parameterObjects": Sequence["ParameterObjectTypeDef"],
+        "parameterValues": Sequence["ParameterValueTypeDef"],
     },
     total=False,
 )
